==> apache-ldap-api-1.0.3-src.zip: apache-ldap-api-1.0.3-src/ldap/client/api/src/test/java/org/apache/directory/ldap/client/api/search/UnaryFilterTest.java <==
/*
 *   Licensed to the Apache Software Foundation (ASF) under one
 *   or more contributor license agreements.  See the NOTICE file
 *   distributed with this work for additional information
 *   regarding copyright ownership.  The ASF licenses this file
 *   to you under the Apache License, Version 2.0 (the
 *   "License"); you may not use this file except in compliance
 *   with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing,
 *   software distributed under the License is distributed on an
 *   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *   KIND, either express or implied.  See the License for the
 *   specific language governing permissions and limitations
 *   under the License.
 *
 */
package org.apache.directory.ldap.client.api.search;


import static org.junit.Assert.assertEquals;

import org.junit.Test;


/**
 * 
 * TODO UnaryFilterTest.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 */
public class UnaryFilterTest
{
    @Test
    public void testNot()
    {
        AttributeDescriptionFilter attributeFilter = AttributeDescriptionFilter.present( "objectClass" );
        assertEquals( "(!" + attributeFilter.build().toString() + ")",
            UnaryFilter.not( attributeFilter ).build().toString() );

        AttributeValueAssertionFilter attributeValueAssertionFilter =
            AttributeValueAssertionFilter.equal( "objectClass", "person" );
        assertEquals( "(!" + attributeValueAssertionFilter.build().toString() + ")",
            UnaryFilter.not( attributeValueAssertionFilter ).build().toString() );
    }
}

==> apache-ldap-api-2.0.0-src.zip: apache-ldap-api-2.0.0-src/ldap/client/api/src/test/java/org/apache/directory/ldap/client/api/search/UnaryFilterTest.java <==
/*
 *   Licensed to the Apache Software Foundation (ASF) under one
 *   or more contributor license agreements.  See the NOTICE file
 *   distributed with this work for additional information
 *   regarding copyright ownership.  The ASF licenses this file
 *   to you under the Apache License, Version 2.0 (the
 *   "License"); you may not use this file except in compliance
 *   with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing,
 *   software distributed under the License is distributed on an
 *   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *   KIND, either express or implied.  See the License for the
 *   specific language governing permissions and limitations
 *   under the License.
 *
 */
package org.apache.directory.ldap.client.api.search;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.junit.jupiter.api.Test;

/**
 * 
 * TODO UnaryFilterTest.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 */
public class UnaryFilterTest
{
    @Test
    public void testNot()
    {
        AttributeDescriptionFilter attributeFilter = AttributeDescriptionFilter.present( "objectClass" );
        assertEquals( "(!" + attributeFilter.build().toString() + ")",
            UnaryFilter.not( attributeFilter ).build().toString() );

        AttributeValueAssertionFilter attributeValueAssertionFilter =
            AttributeValueAssertionFilter.equal( "objectClass", "person" );
        assertEquals( "(!" + attributeValueAssertionFilter.build().toString() + ")",
            UnaryFilter.not( attributeValueAssertionFilter ).build().toString() );
    }
}
